@@ -1,4 +1,5 @@
-import DataLake
+from delta_lake import DataLake
+
 
 class Bronze(DataLake):
 
