@@ -1,5 +1,4 @@
-from DataLake import DataLake
-
+from delta_lake import DataLake
 
 class Silver(DataLake):
     colums_silver_array = []
